@@ -28,6 +28,7 @@
 #' @md
 #'
 #' @export
+#' @importFrom utils packageVersion
 #'
 #' @examples
 #' resultingMeasures <- BiDimRegression(NakayaData)
@@ -116,7 +117,10 @@ function (coord)
 	# calculating the rotation (angle) (=theta)
 	euc_angleRAD <- atan(euc_beta$coeff[2]/euc_beta$coeff[1])
 	euc_angleDEG <- euc_angleRAD*180/pi
-
+	if (euc_beta$coeff[1] < 0)
+	{
+	  euc_angleDEG <- euc_angleDEG + 180
+	}
 	# calculating the shear (gamma)
 	euc_shear = 0L # per definition shear must be ZERO within an Euclidean geometry
 
@@ -155,6 +159,9 @@ function (coord)
 	euc_dDistanceXYSqr <- euc_dDistanceXY*euc_dDistanceXY
 	euc_dMaxXYSqr <- sum((X-Xm)*(X-Xm)+((Y-Ym)*(Y-Ym)))
 	euc_dMaxXY <- sqrt(euc_dMaxXYSqr)
+	euc_diXYSqr <- euc_dDistanceXYSqr/euc_dMaxXYSqr
+	euc_diXY <- sqrt(euc_diXYSqr)
+
 	# --- second: calculating distortion index for target configuration
 	euc_dDistanceAB <- sqrt(sum((A-euc_Apred)*(A-euc_Apred))+sum((B-euc_Bpred)*(B-euc_Bpred)))
 	euc_dDistanceABSqr <- euc_dDistanceAB*euc_dDistanceAB
@@ -163,8 +170,6 @@ function (coord)
 	euc_diABSqr <- euc_dDistanceABSqr/euc_dMaxABSqr
 	euc_diAB <- sqrt(euc_diABSqr)
 
-	euc_diXYSqr <- euc_dDistanceABSqr/euc_dMaxXYSqr
-	euc_diXY <- sqrt(euc_diXYSqr)
 
 	# ------- Calculation of DAIC (Difference AIC = Akaike Information Criterion)
 	#      DAICso: AIC difference DAICso between a bidimensional regression model and
@@ -231,9 +236,9 @@ function (coord)
 	aff_angleRAD <- atan(aff_beta$coeff[3]/aff_beta$coeff[1])
 	aff_angleDEG <- aff_angleRAD*180/pi
 	if (aff_beta$coeff[1] < 0)
-		{
-    		aff_angleDEG <- aff_angleDEG+180
-		}
+	{
+  		aff_angleDEG <- aff_angleDEG+180
+	}
 
 	# calculating the shear (gamma)
 	aff_shear <- (((aff_beta$coeff[4]/aff_beta$coeff[2])*sin(aff_angleRAD))+cos(aff_angleRAD))/
@@ -291,6 +296,10 @@ function (coord)
 	aff_dMaxXY <- sqrt(aff_dMaxXYSqr)
 	euc_dMaxXY <- sqrt(euc_dMaxXYSqr)
 
+	aff_diXYSqr <- aff_dDistanceXYSqr/aff_dMaxXYSqr
+	aff_diXY <- sqrt(aff_diXYSqr)
+
+
 	# --- second: calculating distortion index for target configuration
 	aff_dDistanceAB <- sqrt(sum((A-aff_Apred)*(A-aff_Apred))+sum((B-aff_Bpred)*(B-aff_Bpred)))
 	aff_dDistanceABSqr <- aff_dDistanceAB*aff_dDistanceAB
@@ -299,8 +308,6 @@ function (coord)
 	aff_diABSqr <- aff_dDistanceABSqr/aff_dMaxABSqr
 	aff_diAB <- sqrt(aff_diABSqr)
 
-	aff_diXYSqr <- aff_dDistanceABSqr/aff_dMaxXYSqr
-	aff_diXY <- sqrt(aff_diXYSqr)
 
 
 	# ------- Calculation of DAIC (Difference AIC = Akaike Information Criterion)
@@ -349,145 +356,132 @@ function (coord)
 print.BiDimRegression <-
 function(x, ...)
 {
-  # version of the routine
-  verRoutine <- "1.0.6"
+  # print the results of the BiDimensional Regression Analysis
+  cat(sprintf('\n-------------------\n'))
+  cat(sprintf('BiDimRegression %s \n', packageVersion("BiDimRegression")))
+  cat(sprintf('Date-Time: %s\n', date()))
+  cat(sprintf('----------------------------------------------------------------------\n'))
 
-  # ---- OUTPUT the data ----
-  for(iOutputLoop in 0:1) {
-    if (iOutputLoop == 1) {
-      # declaration of the output file
-      sink(file="BiDimRegrOutput.txt", type="output", append=TRUE)
-    }
+  euc_alpha=matrix(c(x$euclidean.alpha1.coeff, x$euclidean.alpha1.SE, x$euclidean.alpha1.tValue,
+                     x$euclidean.ttestDF, x$euclidean.alpha1.pValue,
+                     x$euclidean.alpha2.coeff, x$euclidean.alpha2.SE, x$euclidean.alpha2.tValue,
+                     x$euclidean.ttestDF, x$euclidean.alpha2.pValue),
+                   nrow=2, byrow = TRUE)
+  euc_beta=matrix(c(x$euclidean.beta1.coeff, x$euclidean.beta1.SE,
+                    x$euclidean.beta1.tValue, x$euclidean.ttestDF, x$euclidean.beta1.pValue,
+                    x$euclidean.beta2.coeff, x$euclidean.beta2.SE, x$euclidean.beta2.tValue,
+                    x$euclidean.ttestDF, x$euclidean.beta2.pValue),
+                  nrow=2, byrow = TRUE)
+  aff_alpha=matrix(c(x$affine.alpha1.coeff, x$affine.alpha1.SE, x$affine.alpha1.tValue,
+                     x$affine.ttestDF, x$affine.alpha1.pValue,
+                     x$affine.alpha2.coeff, x$affine.alpha2.SE, x$affine.alpha2.tValue,
+                     x$affine.ttestDF, x$affine.alpha2.pValue),
+                   nrow=2, byrow = TRUE)
+  aff_beta=matrix(c(x$affine.beta1.coeff, x$affine.beta1.SE, x$affine.beta1.tValue,
+                    x$affine.ttestDF, x$affine.beta1.pValue,
+                    x$affine.beta2.coeff, x$affine.beta2.SE, x$affine.beta2.tValue, x$affine.ttestDF, x$affine.beta2.pValue,
+                    x$affine.beta3.coeff, x$affine.beta3.SE, x$affine.beta3.tValue, x$affine.ttestDF, x$affine.beta3.pValue,
+                    x$affine.beta4.coeff, x$affine.beta4.SE, x$affine.beta4.tValue, x$affine.ttestDF, x$affine.beta4.pValue),
+                  nrow=4, byrow = TRUE)
 
-    # print the results of the BiDimensional Regression Analysis
-    cat(sprintf('\n-------------------\n'))
-    cat(sprintf('BiDimRegression %s \n', verRoutine))
-    cat(sprintf('Date-Time: %s\n', date()))
-    cat(sprintf('----------------------------------------------------------------------\n'))
+  # -- Overall analysis
+  overallStats=matrix(c(
+    x$euclidean.r, x$euclidean.rsqr, x$euclidean.fValue, x$euclidean.df1, x$euclidean.df2, x$euclidean.pValue,
+    x$affine.r, x$affine.rsqr, x$affine.fValue, x$affine.df1, x$affine.df2, x$affine.pValue),
+    nrow=2, byrow = TRUE)
+  colnames(overallStats) <- c("r", "r-sqr", "F-value", "df1", "df2", "p-value")
+  rownames(overallStats) <- c("Euclidean", "Affine")
 
-    euc_alpha=matrix(c(x$euclidean.alpha1.coeff, x$euclidean.alpha1.SE, x$euclidean.alpha1.tValue,
-                       x$euclidean.ttestDF, x$euclidean.alpha1.pValue,
-                       x$euclidean.alpha2.coeff, x$euclidean.alpha2.SE, x$euclidean.alpha2.tValue,
-                       x$euclidean.ttestDF, x$euclidean.alpha2.pValue),
-                     nrow=2, byrow = TRUE)
-    euc_beta=matrix(c(x$euclidean.beta1.coeff, x$euclidean.beta1.SE,
-                      x$euclidean.beta1.tValue, x$euclidean.ttestDF, x$euclidean.beta1.pValue,
-                      x$euclidean.beta2.coeff, x$euclidean.beta2.SE, x$euclidean.beta2.tValue,
-                      x$euclidean.ttestDF, x$euclidean.beta2.pValue),
-                    nrow=2, byrow = TRUE)
-    aff_alpha=matrix(c(x$affine.alpha1.coeff, x$affine.alpha1.SE, x$affine.alpha1.tValue,
-                       x$affine.ttestDF, x$affine.alpha1.pValue,
-                       x$affine.alpha2.coeff, x$affine.alpha2.SE, x$affine.alpha2.tValue,
-                       x$affine.ttestDF, x$affine.alpha2.pValue),
-                     nrow=2, byrow = TRUE)
-    aff_beta=matrix(c(x$affine.beta1.coeff, x$affine.beta1.SE, x$affine.beta1.tValue,
-                      x$affine.ttestDF, x$affine.beta1.pValue,
-                      x$affine.beta2.coeff, x$affine.beta2.SE, x$affine.beta2.tValue, x$affine.ttestDF, x$affine.beta2.pValue,
-                      x$affine.beta3.coeff, x$affine.beta3.SE, x$affine.beta3.tValue, x$affine.ttestDF, x$affine.beta3.pValue,
-                      x$affine.beta4.coeff, x$affine.beta4.SE, x$affine.beta4.tValue, x$affine.ttestDF, x$affine.beta4.pValue),
-                    nrow=4, byrow = TRUE)
+  cat(sprintf('\n--- overall statistics ---\n'))
+  printCoefmat(overallStats, P.values=TRUE, has.Pvalue=TRUE, digits=3, tst.ind=4, signif.stars=TRUE)
 
-    # -- Overall analysis
-    overallStats=matrix(c(
-      x$euclidean.r, x$euclidean.rsqr, x$euclidean.fValue, x$euclidean.df1, x$euclidean.df2, x$euclidean.pValue,
-      x$affine.r, x$affine.rsqr, x$affine.fValue, x$affine.df1, x$affine.df2, x$affine.pValue),
-      nrow=2, byrow = TRUE)
-    colnames(overallStats) <- c("r", "r-sqr", "F-value", "df1", "df2", "p-value")
-    rownames(overallStats) <- c("Euclidean", "Affine")
-
-    cat(sprintf('\n--- overall statistics ---\n'))
-    printCoefmat(overallStats, P.values=TRUE, has.Pvalue=TRUE, digits=3, tst.ind=4, signif.stars=TRUE)
-
-    # show warning for unidentified model
-    if (x$euclidean.df2 < x$euclidean.df1)	{
-      cat(sprintf('WARNING: Euclidean model is not defined'))
-    }
-    if (x$affine.df2 < x$affine.df1) {
-      cat(sprintf('\t\t\t\t\tWARNING: Affine model is not defined\n'))
-    }
-
-    cat(sprintf('----------------------------------------------------------------------\n'))
-    cat(sprintf('\n--- parameters ---\n'))
-    cat(sprintf('\n- Euclidean -\n'))
-
-    # -- Parameter analyses
-    colNames <- c("Parameter", "Std.Err", "t-value", "df", "p-value")
-    rowNamesAlphas <- c("alpha1", "alpha2")
-    rowNames2Betas <- c("beta1 ", "beta2 ")
-    rowNames4Betas <- c("beta1 ", "beta2 ", "beta3 ", "beta4 ")
-    colnames(euc_alpha) <- colNames
-    colnames(euc_beta) <- colNames
-    colnames(aff_alpha) <- colNames
-    colnames(aff_beta) <- colNames
-    rownames(euc_alpha) <- rowNamesAlphas
-    rownames(euc_beta) <- rowNames2Betas
-    rownames(aff_alpha) <- rowNamesAlphas
-    rownames(aff_beta) <- rowNames4Betas
-
-    printCoefmat(euc_alpha, P.values = TRUE, has.Pvalue = TRUE, digits=3, tst.ind=4)
-    cat(sprintf('\n'))
-    printCoefmat(euc_beta, P.values = TRUE, has.Pvalue = TRUE, digits=3, tst.ind=4)
-    cat(sprintf('\n'))
-
-    cat(sprintf('\n- Affine -\n'))
-    printCoefmat(aff_alpha, P.values = TRUE, has.Pvalue = TRUE, digits=3, tst.ind=4)
-    cat(sprintf('\n'))
-    printCoefmat(aff_beta, P.values = TRUE, has.Pvalue = TRUE, digits=3, tst.ind=4)
-    cat(sprintf('\n'))
-
-    cat(sprintf('----------------------------------------------------------------------\n'))
-    cat(sprintf('\n--- details ---\n'))
-    cat(sprintf('\n- Euclidean -\t\t\t- Affine -\n'))
-    cat(sprintf('scaleX\t= scaleY = %4.3f\tscaleX\t= %4.3f, scaleY = %4.3f\n',
-                x$euclidean.scaleFactorX, x$affine.scaleFactorX, x$affine.scaleFactorY))
-    cat(sprintf('shear\t= %4.3f\t\t\tshear\t= %4.3f\n',
-                x$euclidean.shear, x$affine.shear))
-    cat(sprintf('angle\t= %4.3f DEG\t\tangle\t= %4.3f DEG\n',
-                x$euclidean.angleDEG, x$affine.angleDEG))
-
-    cat(sprintf('---\t\t\t\t---\n'))
-    cat(sprintf('DAIC (agst.0)\t= %4.2f\tDAIC (agst.0)\t= %4.2f\n',
-                x$euclidean.dAICso, x$affine.dAICso))
-
-    cat(sprintf('---\t\t\t\t---\n'))
-    cat(sprintf('dMaxABSqr\t= %4.3f\tdMaxABSqr\t= %4.3f\n',
-                x$euclidean.dMaxABSqr, x$affine.dMaxABSqr))
-    cat(sprintf('diABSqr  \t= %4.3f\t\tdiABSqr  \t= %4.3f\n',
-                x$euclidean.diABSqr, x$affine.diABSqr))
-    cat(sprintf('dMaxXYSqr\t= %4.3f\tdMaxXYSqr\t= %4.3f\n',
-                x$euclidean.dMaxXYSqr, x$affine.dMaxXYSqr))
-    cat(sprintf('diXYSqr  \t= %4.3f\t\tdiXYSqr  \t= %4.3f\n',
-                x$euclidean.diXYSqr, x$affine.diXYSqr))
-    cat(sprintf('----------------------------------------------------------------------\n'))
-    cat(sprintf('\n--- comparative statistics of fitted bidimensional regxsion models\n\n'))
-
-    comparativeStats=matrix(c(
-      x$eucVSaff.fValue, as.integer(x$eucVSaff.df1), as.integer(x$eucVSaff.df2), x$eucVSaff.pValue),
-      nrow=1, byrow = TRUE)
-    colnames(comparativeStats) <- c("F-value", "df1", "df2", "p-value")
-    rownames(comparativeStats) <- c("Euclidean vs. Affine")
-    printCoefmat(comparativeStats, P.values=TRUE, has.Pvalue=TRUE, digits=3, cs.ind=1, signif.stars=TRUE)
-
-    cat(sprintf('\n'))
-
-    if (x$eucVSaff.df2 < x$eucVSaff.df1) {
-      cat(sprintf('WARNING: model is not defined\n'))
-    }
-    if (x$eucVSaff.pValue <= .05) {
-      if (x$eucVSaff.dAIC<0) {
-        superiorSolution <- '(significantly better: Affine solution)'
-      } else {
-        superiorSolution <- '(significantly better: Euclidean solution)'
-      }
-    } else {
-      superiorSolution = '(not significantly different solutions)'
-    }
-
-    cat(sprintf('\nDAICea = %4.3f %s\n\n', x$eucVSaff.dAIC, superiorSolution))
-    cat(sprintf('**********************************************************************\n\n\n'))
+  # show warning for unidentified model
+  if (x$euclidean.df2 < x$euclidean.df1)	{
+    cat(sprintf('WARNING: Euclidean model is not defined'))
+  }
+  if (x$affine.df2 < x$affine.df1) {
+    cat(sprintf('\t\t\t\t\tWARNING: Affine model is not defined\n'))
   }
 
-  sink()   # close the output result file
+  cat(sprintf('----------------------------------------------------------------------\n'))
+  cat(sprintf('\n--- parameters ---\n'))
+  cat(sprintf('\n- Euclidean -\n'))
+
+  # -- Parameter analyses
+  colNames <- c("Parameter", "Std.Err", "t-value", "df", "p-value")
+  rowNamesAlphas <- c("alpha1", "alpha2")
+  rowNames2Betas <- c("beta1 ", "beta2 ")
+  rowNames4Betas <- c("beta1 ", "beta2 ", "beta3 ", "beta4 ")
+  colnames(euc_alpha) <- colNames
+  colnames(euc_beta) <- colNames
+  colnames(aff_alpha) <- colNames
+  colnames(aff_beta) <- colNames
+  rownames(euc_alpha) <- rowNamesAlphas
+  rownames(euc_beta) <- rowNames2Betas
+  rownames(aff_alpha) <- rowNamesAlphas
+  rownames(aff_beta) <- rowNames4Betas
+
+  printCoefmat(euc_alpha, P.values = TRUE, has.Pvalue = TRUE, digits=3, tst.ind=4)
+  cat(sprintf('\n'))
+  printCoefmat(euc_beta, P.values = TRUE, has.Pvalue = TRUE, digits=3, tst.ind=4)
+  cat(sprintf('\n'))
+
+  cat(sprintf('\n- Affine -\n'))
+  printCoefmat(aff_alpha, P.values = TRUE, has.Pvalue = TRUE, digits=3, tst.ind=4)
+  cat(sprintf('\n'))
+  printCoefmat(aff_beta, P.values = TRUE, has.Pvalue = TRUE, digits=3, tst.ind=4)
+  cat(sprintf('\n'))
+
+  cat(sprintf('----------------------------------------------------------------------\n'))
+  cat(sprintf('\n--- details ---\n'))
+  cat(sprintf('\n- Euclidean -\t\t\t- Affine -\n'))
+  cat(sprintf('scaleX\t= scaleY = %4.3f\tscaleX\t= %4.3f, scaleY = %4.3f\n',
+              x$euclidean.scaleFactorX, x$affine.scaleFactorX, x$affine.scaleFactorY))
+  cat(sprintf('shear\t= %4.3f\t\t\tshear\t= %4.3f\n',
+              x$euclidean.shear, x$affine.shear))
+  cat(sprintf('angle\t= %4.3f DEG\t\tangle\t= %4.3f DEG\n',
+              x$euclidean.angleDEG, x$affine.angleDEG))
+
+  cat(sprintf('---\t\t\t\t---\n'))
+  cat(sprintf('DAIC (agst.0)\t= %4.2f\tDAIC (agst.0)\t= %4.2f\n',
+              x$euclidean.dAICso, x$affine.dAICso))
+
+  cat(sprintf('---\t\t\t\t---\n'))
+  cat(sprintf('dMaxABSqr\t= %4.3f\tdMaxABSqr\t= %4.3f\n',
+              x$euclidean.dMaxABSqr, x$affine.dMaxABSqr))
+  cat(sprintf('diABSqr  \t= %4.3f\t\tdiABSqr  \t= %4.3f\n',
+              x$euclidean.diABSqr, x$affine.diABSqr))
+  cat(sprintf('dMaxXYSqr\t= %4.3f\tdMaxXYSqr\t= %4.3f\n',
+              x$euclidean.dMaxXYSqr, x$affine.dMaxXYSqr))
+  cat(sprintf('diXYSqr  \t= %4.3f\t\tdiXYSqr  \t= %4.3f\n',
+              x$euclidean.diXYSqr, x$affine.diXYSqr))
+  cat(sprintf('----------------------------------------------------------------------\n'))
+  cat(sprintf('\n--- comparative statistics of fitted bidimensional regxsion models\n\n'))
+
+  comparativeStats=matrix(c(
+    x$eucVSaff.fValue, as.integer(x$eucVSaff.df1), as.integer(x$eucVSaff.df2), x$eucVSaff.pValue),
+    nrow=1, byrow = TRUE)
+  colnames(comparativeStats) <- c("F-value", "df1", "df2", "p-value")
+  rownames(comparativeStats) <- c("Euclidean vs. Affine")
+  printCoefmat(comparativeStats, P.values=TRUE, has.Pvalue=TRUE, digits=3, cs.ind=1, signif.stars=TRUE)
+
+  cat(sprintf('\n'))
+
+  if (x$eucVSaff.df2 < x$eucVSaff.df1) {
+    cat(sprintf('WARNING: model is not defined\n'))
+  }
+  if (x$eucVSaff.pValue <= .05) {
+    if (x$eucVSaff.dAIC<0) {
+      superiorSolution <- '(significantly better: Affine solution)'
+    } else {
+      superiorSolution <- '(significantly better: Euclidean solution)'
+    }
+  } else {
+    superiorSolution = '(not significantly different solutions)'
+  }
+
+  cat(sprintf('\nDAICea = %4.3f %s\n\n', x$eucVSaff.dAIC, superiorSolution))
+  cat(sprintf('**********************************************************************\n\n\n'))
 }
 
 
